@@ -57,7 +57,7 @@ function (x, y, id, initial.values, control) {
     if (!diag.D) dimnames(D) <- NULL else names(D) <- NULL
     # fix environments for functions
     environment(opt.survWB) <- environment(gr.survWB) <- environment()
-    environment(opt.longWB) <- environment(gr.longWB) <- environment()
+    environment(opt.longWB) <- environment(gr.longWB) <- environment(H.longWB) <- environment()
     environment(LogLik.weibullGH) <- environment(Score.weibullGH) <- environment()
     old <- options(warn = (-1))
     on.exit(options(old))
@@ -147,7 +147,7 @@ function (x, y, id, initial.values, control) {
         sigman <- sqrt(c(crossprod(mu, mu - 2 * Zb) + crossprod(Zb) + tr.tZZvarb) / N)
         Dn <- matrix(colMeans(p.byt %*% (b2 * wGH), na.rm = TRUE), ncz, ncz)
         Dn <- if (diag.D) diag(Dn) else 0.5 * (Dn + t(Dn))
-        Hbetas <- nearPD(fd.vec(betas, gr.longWB))
+        Hbetas <- nearPD(H.longWB(betas))
         scbetas <- gr.longWB(betas)
         betasn <- betas - c(solve(Hbetas, scbetas))
         thetas <- c(gammas, alpha, log(sigma.t))
@@ -164,7 +164,9 @@ function (x, y, id, initial.values, control) {
         alpha <- thetasn[ncww + 1]
         sigma.t <- exp(thetasn[ncww + 2])
     }
-    thetas <- c(betas, log(sigma), gammas, alpha, log(sigma.t), if (diag.D) log(D) else chol.transf(D))
+    list.thetas <- list(betas = betas, log.sigma = log(sigma), gammas = gammas, alpha = alpha, 
+        log.sigma.t = log(sigma.t), D = if (diag.D) log(D) else chol.transf(D))
+    thetas <- unlist(as.relistable(list.thetas))
     lgLik <- - LogLik.weibullGH(thetas)    
     # if not converged, start quasi-Newton iterations
     if (!conv && !control$only.EM) {
@@ -181,14 +183,14 @@ function (x, y, id, initial.values, control) {
                 control = list(iter.max = control$iter.qN, trace = 1 * control$verbose))
         }
         if ((conv <- out$convergence) == 0 || - out[[2]] > lgLik) {
-            lgLik <- - out[[2]]
-            thetas <- out$par
-            betas <- thetas[1:ncx]
-            sigma <- exp(thetas[ncx + 1])
-            gammas <- thetas[seq(ncx + 2, ncx + 1 + ncww)]
-            alpha <- thetas[ncx + ncww + 2]
-            sigma.t <- exp(thetas[ncx + ncww + 3])
-            D <- thetas[seq(ncx + ncww + 4, length(thetas))]
+            lgLik <- - out[[2]]            
+            thetas <- relist(out$par, skeleton = list.thetas)
+            betas <- thetas$betas
+            sigma <- exp(thetas$log.sigma)
+            gammas <- thetas$gammas
+            alpha <- thetas$alpha
+            sigma.t <- exp(thetas$log.sigma.t)
+            D <- thetas$D
             D <- if (diag.D) exp(D) else chol.transf(D)
             it <- it + if (control$optimizer == "optim") out$counts[1] else out$iterations
             # compute posterior moments for thetas after quasi-Newton
@@ -231,9 +233,9 @@ function (x, y, id, initial.values, control) {
     }
     # calculate Hessian matrix
     Hessian <- if (control$numeriDeriv == "fd") {
-        fd.vec(thetas, Score.weibullGH, eps = control$eps.Hes)
+        fd.vec(unlist(thetas), Score.weibullGH, eps = control$eps.Hes)
     } else { 
-        cd.vec(thetas, Score.weibullGH, eps = control$eps.Hes)
+        cd.vec(unlist(thetas), Score.weibullGH, eps = control$eps.Hes)
     }
     names(betas) <- names(initial.values$betas)
     if (!diag.D) dimnames(D) <- dimnames(initial.values$D) else names(D) <- names(initial.values$D)
